---
title: <span class="badge object-type-scalar"></span> PetaFlopsPerSecond
---
# <span class="badge object-type-scalar"></span> PetaFlopsPerSecond

Computation: PFLOP/s

## Definition

```python
# Computation: PFLOP/s
PetaFlopsPerSecond: typing.Literal["pflops"] = "pflops"
```
